==> qtjambi-qt3dcore-debuginfo-linux-x64-5.15.18.jar: sources/QtJambi3DCore/QSceneChange_shell.cpp <==
#include "QSceneChange_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_Qt3DCore_QSceneChange(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QSceneChange")
    Qt3DCore::QSceneChange *_ptr = reinterpret_cast<Qt3DCore::QSceneChange *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QSceneChange_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QSceneChange_shell) ); }

jmethodID QSceneChange_shell::__shell_javaMethod(int pos) const { return QSceneChange_shell::__shell()->javaMethod(typeid(Qt3DCore::QSceneChange), pos); }

// emitting (writeShellConstructor)
QSceneChange_shell::QSceneChange_shell(qint32 type0, Qt3DCore::QNodeId subjectId1)
    : Qt3DCore::QSceneChange(Qt3DCore::ChangeFlag(type0), subjectId1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DCore::QSceneChange::QSceneChange_shell(Qt3DCore::ChangeFlag type0, Qt3DCore::QNodeId subjectId1)", QSceneChange_shell::__shell())
    QSceneChange_shell::__shell()->constructed(typeid(Qt3DCore::QSceneChange));
}

// emitting (writeShellDestructor)
QSceneChange_shell::~QSceneChange_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DCore::QSceneChange::~Qt3DCore::QSceneChange()", QSceneChange_shell::__shell())
    QSceneChange_shell::__shell()->destructed(typeid(Qt3DCore::QSceneChange));
}

void QSceneChange_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSceneChange_shell*>(ptr)->QSceneChange_shell::__shell()->tryDeleteShell(typeid(Qt3DCore::QSceneChange));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QSceneChange(Qt3DCore::ChangeFlag,Qt3DCore::QNodeId)
void __qt_construct_Qt3DCore_QSceneChange_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSceneChange(Qt3DCore::ChangeFlag,Qt3DCore::QNodeId)")
    jobject type0 = __java_arguments[0].l;
    Qt3DCore::ChangeFlag __qt_type0 = qtjambi_cast<Qt3DCore::ChangeFlag>(__jni_env, type0);
    jobject subjectId1 = __java_arguments[1].l;
    Qt3DCore::QNodeId __qt_subjectId1 = qtjambi_cast<Qt3DCore::QNodeId >(__jni_env, subjectId1);
    Qt3DCore::QSceneChange *__qt_this = new(__qtjambi_ptr) QSceneChange_shell(Qt3DCore::ChangeFlag(__qt_type0), __qt_subjectId1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QSceneChange_shell
void __qt_destruct_Qt3DCore_QSceneChange(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QSceneChange")
    reinterpret_cast<QSceneChange_shell*>(ptr)->~QSceneChange_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DCore::QSceneChange::QSceneChange(Qt3DCore::ChangeFlag,Qt3DCore::QNodeId)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QSceneChange_initialize_1native__Lio_qt_qt3d_core_QSceneChange_2Lio_qt_qt3d_core_Qt3DCore_00024ChangeFlag_2Lio_qt_qt3d_core_QNodeId_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject type0,
 jobject subjectId1)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QSceneChange::QSceneChange(Qt3DCore::ChangeFlag,Qt3DCore::QNodeId)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = type0;
        arguments[1].l = subjectId1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QSceneChange_0, sizeof(QSceneChange_shell), typeid(Qt3DCore::QSceneChange), true, &deleter_Qt3DCore_QSceneChange, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DCore::QSceneChange::deliveryFlags()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QSceneChange_deliveryFlags_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QSceneChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QSceneChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QSceneChange::deliveryFlags()const", __qt_this)
        Qt3DCore::QSceneChange::DeliveryFlags __qt_return_value = __qt_this->deliveryFlags();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QSceneChange::setDeliveryFlags(Qt3DCore::QSceneChange::DeliveryFlags)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QSceneChange_setDeliveryFlags_1native_1Qt3DCore_1QSceneChange_1DeliveryFlags__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint flags0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        Qt3DCore::QSceneChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QSceneChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QSceneChange::setDeliveryFlags(Qt3DCore::QSceneChange::DeliveryFlags)", __qt_this)
        Qt3DCore::QSceneChange::DeliveryFlags __qt_flags0 = qtjambi_cast<Qt3DCore::QSceneChange::DeliveryFlags>(__jni_env, flags0);
        __qt_this->setDeliveryFlags(Qt3DCore::QSceneChange::DeliveryFlags(__qt_flags0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DCore::QSceneChange::subjectId()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QSceneChange_subjectId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QSceneChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QSceneChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QSceneChange::subjectId()const", __qt_this)
        Qt3DCore::QNodeId __qt_return_value = __qt_this->subjectId();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QSceneChange::type()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QSceneChange_type_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QSceneChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QSceneChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QSceneChange::type()const", __qt_this)
        Qt3DCore::ChangeFlag __qt_return_value = __qt_this->type();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DCore_QSceneChange(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<Qt3DCore::QSceneChange>("Qt3DCore::QSceneChange", "io/qt/qt3d/core/QSceneChange");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QSceneChange, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QSceneChange_0, "Lio/qt/qt3d/core/Qt3DCore$ChangeFlag;Lio/qt/qt3d/core/QNodeId;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QSceneChange);
    registerSizeOfShell(typeId, sizeof(QSceneChange_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<Qt3DCore::QSceneChange::DeliveryFlag>("Qt3DCore::QSceneChange::DeliveryFlag", "io/qt/qt3d/core/QSceneChange$DeliveryFlag", "Qt3DCore::QSceneChange::DeliveryFlags", "QFlags<Qt3DCore::QSceneChange::DeliveryFlag>", "io/qt/qt3d/core/QSceneChange$DeliveryFlags");
// END: enums and flags
}

==> qtjambi-qt3dcore-debuginfo-linux-x64-5.15.20.jar: sources/QtJambi3DCore/QSceneChange_shell.cpp <==
#include "QSceneChange_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_Qt3DCore_QSceneChange(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QSceneChange")
    Qt3DCore::QSceneChange *_ptr = reinterpret_cast<Qt3DCore::QSceneChange *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QSceneChange_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QSceneChange_shell) ); }

jmethodID QSceneChange_shell::__shell_javaMethod(int pos) const { return QSceneChange_shell::__shell()->javaMethod(typeid(Qt3DCore::QSceneChange), pos); }

// emitting (writeShellConstructor)
QSceneChange_shell::QSceneChange_shell(qint32 type0, Qt3DCore::QNodeId subjectId1)
    : Qt3DCore::QSceneChange(Qt3DCore::ChangeFlag(type0), subjectId1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DCore::QSceneChange::QSceneChange_shell(Qt3DCore::ChangeFlag type0, Qt3DCore::QNodeId subjectId1)", QSceneChange_shell::__shell())
    QSceneChange_shell::__shell()->constructed(typeid(Qt3DCore::QSceneChange));
}

// emitting (writeShellDestructor)
QSceneChange_shell::~QSceneChange_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DCore::QSceneChange::~Qt3DCore::QSceneChange()", QSceneChange_shell::__shell())
    QSceneChange_shell::__shell()->destructed(typeid(Qt3DCore::QSceneChange));
}

void QSceneChange_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSceneChange_shell*>(ptr)->QSceneChange_shell::__shell()->tryDeleteShell(typeid(Qt3DCore::QSceneChange));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QSceneChange(Qt3DCore::ChangeFlag,Qt3DCore::QNodeId)
void __qt_construct_Qt3DCore_QSceneChange_Qt3DCore_ChangeFlag_Qt3DCore_QNodeId(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSceneChange(Qt3DCore::ChangeFlag,Qt3DCore::QNodeId)")
    jobject type0 = __java_arguments[0].l;
    Qt3DCore::ChangeFlag __qt_type0 = qtjambi_cast<Qt3DCore::ChangeFlag>(__jni_env, type0);
    jobject subjectId1 = __java_arguments[1].l;
    Qt3DCore::QNodeId __qt_subjectId1 = qtjambi_cast<Qt3DCore::QNodeId >(__jni_env, subjectId1);
    Qt3DCore::QSceneChange *__qt_this = new(__qtjambi_ptr) QSceneChange_shell(Qt3DCore::ChangeFlag(__qt_type0), __qt_subjectId1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// Qt3DCore::QSceneChange::QSceneChange(Qt3DCore::ChangeFlag,Qt3DCore::QNodeId)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QSceneChange_initialize_1native__Lio_qt_qt3d_core_QSceneChange_2Lio_qt_qt3d_core_Qt3DCore_00024ChangeFlag_2Lio_qt_qt3d_core_QNodeId_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject type0,
 jobject subjectId1)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QSceneChange::QSceneChange(Qt3DCore::ChangeFlag,Qt3DCore::QNodeId)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = type0;
        arguments[1].l = subjectId1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QSceneChange_Qt3DCore_ChangeFlag_Qt3DCore_QNodeId, sizeof(QSceneChange_shell), typeid(Qt3DCore::QSceneChange), true, &deleter_Qt3DCore_QSceneChange, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QSceneChange_shell
void __qt_destruct_Qt3DCore_QSceneChange(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QSceneChange")
    reinterpret_cast<QSceneChange_shell*>(ptr)->~QSceneChange_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DCore::QSceneChange::deliveryFlags()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QSceneChange_deliveryFlags_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QSceneChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QSceneChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QSceneChange::deliveryFlags()const", __qt_this)
        Qt3DCore::QSceneChange::DeliveryFlags __qt_return_value = __qt_this->deliveryFlags();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QSceneChange::setDeliveryFlags(Qt3DCore::QSceneChange::DeliveryFlags)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QSceneChange_setDeliveryFlags_1native_1Qt3DCore_1QSceneChange_1DeliveryFlags__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint flags0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        Qt3DCore::QSceneChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QSceneChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QSceneChange::setDeliveryFlags(Qt3DCore::QSceneChange::DeliveryFlags)", __qt_this)
        Qt3DCore::QSceneChange::DeliveryFlags __qt_flags0 = qtjambi_cast<Qt3DCore::QSceneChange::DeliveryFlags>(__jni_env, flags0);
        __qt_this->setDeliveryFlags(Qt3DCore::QSceneChange::DeliveryFlags(__qt_flags0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DCore::QSceneChange::subjectId()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QSceneChange_subjectId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QSceneChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QSceneChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QSceneChange::subjectId()const", __qt_this)
        Qt3DCore::QNodeId __qt_return_value = __qt_this->subjectId();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QSceneChange::type()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QSceneChange_type_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QSceneChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QSceneChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QSceneChange::type()const", __qt_this)
        Qt3DCore::ChangeFlag __qt_return_value = __qt_this->type();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DCore_QSceneChange(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<Qt3DCore::QSceneChange>("Qt3DCore::QSceneChange", "io/qt/qt3d/core/QSceneChange");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QSceneChange, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QSceneChange_Qt3DCore_ChangeFlag_Qt3DCore_QNodeId, "Lio/qt/qt3d/core/Qt3DCore$ChangeFlag;Lio/qt/qt3d/core/QNodeId;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QSceneChange);
    registerSizeOfShell(typeId, sizeof(QSceneChange_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<Qt3DCore::QSceneChange::DeliveryFlag>("Qt3DCore::QSceneChange::DeliveryFlag", "io/qt/qt3d/core/QSceneChange$DeliveryFlag", "Qt3DCore::QSceneChange::DeliveryFlags", "QFlags<Qt3DCore::QSceneChange::DeliveryFlag>", "io/qt/qt3d/core/QSceneChange$DeliveryFlags");
// END: enums and flags
}
